@@ -1,11 +1,14 @@
-from nonebot import on_command
-from nonebot.adapters.cqhttp import Bot, MessageEvent, Message, MessageSegment
 import base64
-from .get_weather import *
-from .convrt_pic import *
+import re
 from io import BytesIO
 
-weather = on_command("天气", priority=1)
+from nonebot import on_regex
+from nonebot.adapters.cqhttp import Bot, Message, MessageEvent, MessageSegment
+
+from .convrt_pic import *
+from .get_weather import *
+
+weather = on_regex(r".*?(.*)天气.*?", priority=1)
 
 
 def img_to_b64(pic: Image.Image) -> str:
@@ -15,14 +18,24 @@ def img_to_b64(pic: Image.Image) -> str:
     return "base64://" + base64_str
 
 
+def get_msg(msg) -> str:
+    msg1 = re.search(r".*?(.*)天气.*?", msg)
+    msg2 = re.search(r".*?天气(.*).*?", msg)
+    msg1 = msg1.group(1).replace(" ", "")
+    msg2 = msg2.group(1).replace(" ", "")
+    msg = msg1 if msg1 else msg2
+
+    return msg
+
+
 @weather.handle()
 async def _(bot: Bot, event: MessageEvent):
-    city = str(event.get_message())
+    city = get_msg(event.get_plaintext())
     if city:
         try:
             data = await get_City_Weather(city)
         except KeyError:
-            await weather.finish("这个地方不在天气数据库中哦 >_<")
+            pass
         img = draw(data)
         b64 = img_to_b64(img)
         await weather.finish(MessageSegment.image(b64))
